@@ -39,62 +39,60 @@
    /* Put the tokens into the symbol table, so that GDB and other debuggers
       know about them.  */
    enum yytokentype {
-     tADD = 258,
-     tSUBTRACT = 259,
-     tMULTIPLY = 260,
-     tDIVIDE = 261,
-     tABS = 262,
-     tABS_FUNC = 263,
-     tACOS = 264,
-     tACOSH = 265,
-     tAND = 266,
-     tANS = 267,
-     tASIN = 268,
-     tASINH = 269,
-     tATAN = 270,
-     tATANH = 271,
-     tCBRT = 272,
-     tCHS = 273,
-     tCLR = 274,
-     tCOS = 275,
-     tCOSH = 276,
-     tEXP = 277,
-     tFRAC = 278,
-     tINT = 279,
-     tLN = 280,
-     tLOG10 = 281,
-     tLOG2 = 282,
-     tMOD = 283,
-     t1S = 284,
-     t2S = 285,
-     tNOT = 286,
-     tOR = 287,
-     tPI = 288,
-     tRAND = 289,
-     tRCL = 290,
-     tSIN = 291,
-     tSINH = 292,
-     tROOT = 293,
-     tROOT3 = 294,
-     tROOT4 = 295,
-     tSQUARED = 296,
-     tCUBED = 297,
-     tSQRT = 298,
-     tSTO = 299,
-     tTAN = 300,
-     tTANH = 301,
-     tTRUNC = 302,
-     tXNOR = 303,
-     tXOR = 304,
-     tNUMBER = 305,
-     tREG = 306,
-     NEG = 307,
-     MED = 308,
-     LNEG = 309,
-     POS = 310,
-     HIGH = 311
+     tNUMBER = 258,
+     UNARY_PLUS = 259,
+     tSUBTRACT = 260,
+     tADD = 261,
+     tXNOR = 262,
+     tXOR = 263,
+     tOR = 264,
+     tAND = 265,
+     MULTIPLICATION = 266,
+     tMOD = 267,
+     tDIVIDE = 268,
+     tMULTIPLY = 269,
+     tNOT = 270,
+     tROOT4 = 271,
+     tROOT3 = 272,
+     tROOT = 273,
+     tFUNCTION = 274,
+     tPI = 275,
+     tVARIABLE = 276,
+     tSUPNUM = 277,
+     tSUBNUM = 278,
+     BOOLEAN_OPERATOR = 279,
+     PERCENTAGE = 280,
+     UNARY_MINUS = 281,
+     tINVERSE = 282
    };
 #endif
+/* Tokens.  */
+#define tNUMBER 258
+#define UNARY_PLUS 259
+#define tSUBTRACT 260
+#define tADD 261
+#define tXNOR 262
+#define tXOR 263
+#define tOR 264
+#define tAND 265
+#define MULTIPLICATION 266
+#define tMOD 267
+#define tDIVIDE 268
+#define tMULTIPLY 269
+#define tNOT 270
+#define tROOT4 271
+#define tROOT3 272
+#define tROOT 273
+#define tFUNCTION 274
+#define tPI 275
+#define tVARIABLE 276
+#define tSUPNUM 277
+#define tSUBNUM 278
+#define BOOLEAN_OPERATOR 279
+#define PERCENTAGE 280
+#define UNARY_MINUS 281
+#define tINVERSE 282
+
 
 
 
@@ -103,15 +101,16 @@ typedef union YYSTYPE
 {
 
 /* Line 1676 of yacc.c  */
-#line 41 "./mp-equation-parser.y"
+#line 101 "./mp-equation-parser.y"
 
   MPNumber int_t;
   int integer;
+  char *name;
 
 
 
 /* Line 1676 of yacc.c  */
-#line 115 "mp-equation-parser.h"
+#line 114 "mp-equation-parser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
